@@ -32,6 +32,7 @@ extern "C"
 	void * openmpt_module_create_from_memory(const void * filedata, size_t filesize, void *logfunc, void * user,void * ctls);
 	void openmpt_module_destroy(void * mod);
 	int openmpt_module_read_float_stereo(void * mod, int samplerate, size_t count, float * left, float * right);
+	void openmpt_module_set_repeat_count(void* mod, int repeat_count);
 }
 
 namespace SoLoud
@@ -40,6 +41,7 @@ namespace SoLoud
 	{
 		mParent = aParent;
 		mModfile = openmpt_module_create_from_memory((const void*)mParent->mData, mParent->mDataLen, NULL, NULL, NULL);		
+		openmpt_module_set_repeat_count(mModfile, -1);
 		mPlaying = mModfile != NULL;		
 	}
 
